PROGRAM_NAME='Muxalb_AMX_Driver_Ex1'
(***********************************************************)
(*  FILE CREATED ON: 01/09/2017  AT: 11:19:06              *)
(***********************************************************)
(***********************************************************)
(***********************************************************)
(*  FILE_LAST_MODIFIED_ON: 01/10/2017  AT: 13:47:02        *)
(***********************************************************)
(* System Type : NetLinx                                   *)
(***********************************************************)
(* REV HISTORY:                                            *)
(***********************************************************)
(*
    $History: $
*)
(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_DEVICE
dvMuxLab = 0:4:0 //IP Port to connect to MuxLab controller
dvIPAD = 10001:1:0 //iPad Interface

(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT
long lMuxLabPort = 80 //MuxLab TCP Port number
char chMuxLabIP[] = '192.168.168.50' //IP Address of MuxLab controller
integer target = 1
integer ack = 1
integer  feed_back = 1
integer preset_ID = 1
integer feed_back = 1
char user[] = 'admin' 
char password[] = 'admin'
integer portIn = 1
integer portOut = 1
integer portInDisconnect = 0
char hex_data[] = 'AABBCCDD'//example of hexadecimal data
(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_VARIABLE
volatile integer nMuxLabOnline //Variable to keep track if MuxLab is online with AMX
volatile strHttpHeader[300] //HTTP Header


(***********************************************************)
(*        SUBROUTINE/FUNCTION DEFINITIONS GO BELOW         *)
(***********************************************************)
(* EXAMPLE: DEFINE_FUNCTION <RETURN_TYPE> <NAME> (<PARAMETERS>) *)
(* EXAMPLE: DEFINE_CALL '<NAME>' (<PARAMETERS>) *)
DEFINE_FUNCTION fnSelectMuxLabPreset(integer nPreset) //Function used to pass preset number
{
  fnSendData("'{"p_targetId":1,"p_cmd":"select_preset","p_userName":"admin","p_password":"admin","p_data":[{"presetId":"',itoa(nPreset),'"}]}'")
}

DEFINE_FUNCTION connectionM (integer ntarget , char nuser[] , char npassword[] , integer nportIn , integer nportOut)
{
fnSendData("'{"p_targetId":',itoa(ntarget),',"p_cmd":"connection","p_userName":"',nuser,'","p_password":"', npassword, '","p_data":[{"portIn":"', itoa(nportIn),'","portOut":"', itoa(nportOut),'"}]}'")
	
}

define_function sendDataToRS232 (integer ntarget,  char nuser[], char npassword[], integer nport, char nhex_data[], integer nack, integer nfeed_back)
{
fnSendData("'{"p_targetId":',itoa(ntarget),',"p_cmd":"send_data_to_rs232","p_userName":"',nuser,'","p_password":"', npassword, '","p_data":[{"portIn":"', itoa(nport),'","hexdata":"', nhex_data ,'","ack":',itoa(nack),',"feedback":',itoa(nfeed_back),'}]}'")


}

define_function sendDataToIr (integer ntarget, char nuser[], char npassword[], integer nport, char nhex_data[])
{
fnSendData("'{"p_targetId":',itoa(ntarget),',"p_cmd":"send_data_to_ir","p_userName":"',nuser,'","p_password":"', npassword, '","p_data":[{"portIn":"', itoa(nport),'","hexdata":"', nhex_data,'"}]}'")

}

define_function applyVideoWall (integer ntarget, char nuser[], char npassword[], integer nvwConfigId)
{

fnSendData("'{"p_targetId":',itoa(ntarget),',"p_cmd":"vwApplyConfig","p_userName":"',nuser,'","p_password":"', npassword, '","p_data":[{"vwConfigId":"', itoa(nvwConfigId),'"}]}'")

}






define_function preset (integer ntarget, char nuser[], char npassword[], integer npresetId)
{
fnSendData("'{"p_targetId":',itoa(ntarget),',"p_cmd":"select_preset","p_userName":"',nuser,'","p_password":"', npassword, '","p_data":[{"presetId":"', itoa(npresetId),'"}]}'")

}

// the following function can be called to apply video wall config using a different source (portId)

define_function applyVideoWallNewSource (integer ntarget, char nuser[], char npassword[], integer nvwConfigId, integer newPortId)
{

fnSendData("'{"p_targetId":',itoa(ntarget),',"p_cmd":"vwApplyConfig","p_userName":"',nuser,'","p_password":"', npassword, '","p_data":[{"vwConfigId":"', itoa(nvwConfigId),'","portIn":"', itoa(newPortId),'"}]}'")

}




DEFINE_FUNCTION fnSendData(strJSONData[500])
{
  if(!nMuxLabOnline) //If MuxLab isn't online with AMX
  {
	ip_client_open(dvMuxLab.PORT,chMuxLabIP,lMuxLabPort,IP_TCP)
  }
  wait_until (nMuxLabOnline == TRUE)
  {
	send_string dvMuxLab,"strHttpHeader,itoa(length_array(strJSONData)),$0d,$0a,$0d,$0a,strJSONData"
	wait 4
	{
	  ip_client_close(dvMuxLab.PORT) //Used only to ensure that the socket is closed if MuxLab receives a non-valid command.
	}
  }
}
DEFINE_START
strHttpHeader = "'POST /mnc/secure_api.php HTTP/1.1',$0d,$0a,'HOST: ',chMuxLabIP,$0d,$0a,'Connection:Keep-alive',$0d ,$0a,'content-type: application/json',$0d,$0a,'content-length: '"

(***********************************************************)
(*                THE EVENTS GO BELOW                      *)
(***********************************************************)
DEFINE_EVENT
//button to set the mode and screen state
button_event[dvIPAD,1] //Connect 
{
  push:
  {
	connectionM (target, user, password, portIn, portOut)
	
  }
}



button_event[dvIPAD,2] //Disconnect 
{
  push:
  {
	connectionM (target, user, password, portInDisconnect, portOut)
  }
}
button_event[dvIPAD,3] //send data to RS232
{
  push:
  {

	sendDataToRS232 (target, user, password, portIn, hex_data, ack, feed_back)
  }
}
button_event[dvIPAD,4] //send data to IR.
{
  push:
  {
  
     sendDataToIr (target, user, password, portIn, hex_data)
 
 }
}

button_event[dvIPAD,5] //apply video wall.
{
  push:
  {
      applyVideoWall (target, user, password, preset_ID)
  }
}

button_event[dvIPAD,6] //apply preset.
{
  push:
  {
      preset (target, user, password, preset_ID)

  }
}


data_event[dvMuxLab]
{
  online:
  {
	nMuxLabOnline = TRUE
	send_string 0,"'MuxLab is online.'"
  }
  offline:
  {
	nMuxLabOnline = FALSE
	send_string 0,"'MuxLab is offline.'"
  }
  onerror:
  {
	nMuxLabOnline = FALSE
  }
  string:
  {
	send_string 0,"'RECEIVED DATA from MuxLab:>',data.text"
  }
}
(*****************************************************************)
(*                       END OF PROGRAM                          *)
(*                                                               *)
(*         !!!  DO NOT PUT ANY CODE BELOW THIS COMMENT  !!!      *)
(*                                                               *)
(*****************************************************************)


